:mod:`lasagne.objectives`
=========================

.. automodule:: lasagne.objectives


Loss functions
--------------

.. autofunction:: binary_crossentropy
.. autofunction:: categorical_crossentropy
.. autofunction:: squared_error


Aggregation functions
---------------------

.. autofunction:: aggregate

